@@ -314,7 +314,10 @@ class Calendars(Models, ItemModelDecorator):
         for i in range(self.size()):
             if i + 1 < self.size():
                 if bookings[i].date_ended < bookings[i + 1].date_started:
-                    return [bookings[i].date_ended, bookings[i + 1].date_started]
+                    if closest_operating_date < bookings[i].date_ended:
+                        return [bookings[i].date_ended, bookings[i + 1].date_started] # Original
+                    elif closest_operating_date < bookings[i + 1].date_started:
+                        return [closest_operating_date, bookings[i + 1].date_started]
             elif bookings[0].date_started > closest_operating_date:
                 if closest_operating_date >= self.date_started:
                     return [closest_operating_date, bookings[0].date_started]
@@ -322,8 +325,13 @@ class Calendars(Models, ItemModelDecorator):
                     return [self.date_started, bookings[0].date_started]
                 else:
                     return [bookings[i].date_ended, self.date_ended]
+            elif closest_operating_date < self.date_ended:
+                if closest_operating_date > bookings[i].date_ended:
+                    return [closest_operating_date, self.date_ended]
+                else:
+                    return [bookings[i].date_ended, self.date_ended]
             else:
-                return [bookings[i].date_ended, self.date_ended]
+                return [closest_operating_date, closest_operating_date]
 
     #schedules a reservation if valid, returns false if not, returns none if expired item
     def scheduler(self, new_res, bookings=None):
